.. toctree::
   :maxdepth: 2
   :caption: Contents:

   module_docs/investate/backtesting_examples
   module_docs/investate/moving_average
   module_docs/investate/quandl_data
   module_docs/investate/real_estate_vs_stock
   module_docs/investate/regular_stock_invest
   module_docs/investate/series_utils
   module_docs/investate/streamlit_house_app
   module_docs/investate/test_real_estate_vs_stock
